<?php

namespace App\Distributor\Controllers;

use App\Distributor\Repositories\DistProductCategory;
use App\Distributor\Repositories\DistProductCategoryB;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Layout\Content;
use Dcat\Admin\Admin;

class DistProductCategoryController extends AdminController
{
    /**
     * page index
     */
    public function index(Content $content)
    {
        return $content
            ->header(admin_trans('admin.proudct_category'))
            ->description('')
            ->body($this->grid());
    }

    /**
     * Edit interface.
     *
     * @param  mixed  $id
     * @param  Content  $content
     * @return Content
     */
    public function edit($id, Content $content)
    {
        return $content
            ->translation($this->translation())
            ->title($this->title())
            ->description($this->description()['edit'] ?? trans('admin.edit'))
            ->body($this->form()->edit($id));
    }

    /**
     * Create interface.
     *
     * @param  Content  $content
     * @return Content
     */
    public function create(Content $content)
    {
        return $content
            ->translation($this->translation())
            ->title($this->title())
            ->description($this->description()['create'] ?? trans('admin.create'))
            ->body($this->form());
    }



    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new DistProductCategory(), function (Grid $grid) {
            $grid->column('id','ID')->bold();//->sortable();
            $grid->column('name')->display(function ($name) {
                return html_entity_decode($name); // 或者直接返回 $name，如果你确定不需要转义
            });
            $grid->column('parent_id');
            //$grid->column('distProductParameter.name',admin_trans_label('parameter_name'));
            $grid->column('order');//->orderable();
            $grid->column('enabled')->switch();
            $grid->column('created_at');
            $grid->column('updated_at');//->sortable();
//            $grid->filter(function (Grid\Filter $filter) {
//                $filter->like('name');
//            });
            $grid->disableViewButton();
            $grid->showQuickEditButton();
            $grid->enableDialogCreate();
            $grid->disableEditButton();

            //$grid->quickSearch('name');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new DistProductCategory(), function (Form $form) {
            $form->display('id', 'ID');
            $form->select('parent_id', admin_trans_field('parent'))
                ->options(DistProductCategory::selectMainOptions(function ($query) {
                    // 在这里定义查询条件
                    $query->where('parent_id', 0);
                }))
                ->saving(function ($v) {
                    return (int) $v;
                });
            $form->text('name')->required();
            $form->text('order')
                ->default(0)
                ->rules('numeric')
                ->help(admin_trans_label('order_tips')); // 添加备注
            $form->switch('enabled')->default(1);
          //  $form->select('parameter_id', 'parameter')->options(DistProductParameter::selectOptions())->required();// DIST不需要绑定 parameter
          //  $form->display('created_at');
          //  $form->display('updated_at');
        });
    }
}
