<?php

namespace App\Distributor\Repositories;

use App\Models\DistProductCategory as Model;

use App\Models\DistProductParameter;
use Dcat\Admin\Repositories\EloquentRepository;

class DistProductCategory extends EloquentRepository
{
    /**
     * Model.
     *
     * @var string
     */
    protected $eloquentClass = Model::class;


    // 调用模型方法
    public static function selectMainOptions(\Closure $closure = null)
    {

        $query = Model::query();

        if ($closure) {
            $closure($query);
        }

        // 确保查询构造器不为空
        if (!$query) {
            return [];
        }

        // 返回键值对数组，并按 'name' 和 'order' 字段排序
        $results = $query->orderBy('name')->orderBy('order')->pluck('name', 'id');

        // 在每个 name 前面加上 '├─'
        $results = $results->map(function ($name) {
            return '├─' . $name;
        });

        return $results->all();

    }

    // 调用模型方法
    public static function selectOptions(\Closure $closure = null)
    {
        $selectOptions = Model::class::selectOptions($closure);
        return $selectOptions;
    }


    public static function getParameter($categoryId)
    {
        $categoryRow =  Model::Class::find($categoryId);
        if ($categoryRow->baseProductParameter) {
            return $categoryRow->baseProductParameter->content;
        } else {
            return "[]";
        }
    }

    /**
     * @param Grid\Model|\Dcat\Admin\Grid\Model $model
     * @return array
     */
    public function get(Grid\Model|\Dcat\Admin\Grid\Model $model)
    {
        $obj = new Model();

        // 将树结构转换为数组
        $tree = $obj->toTree();
        $data=[];

        foreach ($tree as $key => $value)
        {
            $node = $value->toArray();


            if(isset($node['children']))
            {
                $clone_node= $node;
                unset($clone_node['children']);
                $data[] = $clone_node;

                $sub_data=$this->flattenTree($node['children']); // 递归扁平化子节点

                //var_dump($sub_data);
                $data = array_merge($data, $sub_data);
            }
            else
            {
                $data[] = $node;

           }
        }

        return $model->makePaginator(
            1, // 传入总记录数
            $data // 传入数据二维数组
        );
    }

    /**
     * @param array $nodes
     * @param $level 默认层级
     * @return array
     */
    function flattenTree(array $nodes, $level = 1)
    {
        $flat = [];

        foreach ($nodes as $node) {
            // 创建一个副本并转换为数组
            $node = $node->toArray();
            $nodeCopy = $node;
            unset($nodeCopy['children']);

            // 根据层级在 name 字段前添加空格
            $nodeCopy['name'] = str_repeat('&nbsp; ', $level * 2). ' <i class="fa fa-angle-right"></i>&nbsp; ' . $nodeCopy['name'];

            // 将去除 'children' 属性的节点添加到平坦数组中
            $flat[] = $nodeCopy;

            // 如果存在子节点，则递归处理子节点
            if (isset($node['children']) && is_array($node['children']))
            {
                $flat = array_merge($flat, $this->flattenTree($node['children'], $level + 1));
            }

        }

        return $flat;
    }
}
